@@ -63,13 +63,6 @@ class LocalPlay
         return $this->_player instanceof localplay_controller;
     }
 
-    /**
-     * format
-     */
-    public function format(): void
-    {
-    }
-
     /**
      * _load_player
      * This function attempts to load the player class that Localplay
@@ -583,6 +576,17 @@ class LocalPlay
         }
     }
 
+    /**
+     * set_block_clear
+     * This stops the mpd system clearing the list when the player is stopped
+     */
+    public function set_block_clear(bool $bool): void
+    {
+        if (isset($this->_player->block_clear)) {
+            $this->_player->block_clear = $bool;
+        }
+    }
+
     /**
      * delete_track
      * This removes songs from the players playlist it takes a single ID as provided
