@@ -238,23 +238,6 @@ class AlbumDisk extends database_object implements library_item, CatalogItemInte
         return (int)$album_id;
     }
 
-    /**
-     * format
-     * This is the format function for this object. It sets cleaned up
-     * album information with the base required
-     * f_link, f_name
-     */
-    public function format(): void
-    {
-        if ($this->isNew()) {
-            return;
-        }
-
-        if (!isset($this->album)) {
-            $this->album = new Album($this->album_id);
-        }
-    }
-
     /**
      * does the item have art?
      */
@@ -476,18 +459,19 @@ class AlbumDisk extends database_object implements library_item, CatalogItemInte
 
     /**
      * Get item children.
-     * @return list<array{object_type: LibraryItemEnum, object_id: int}>
+     * @return array{song: list<array{object_type: LibraryItemEnum, object_id: int}>}
      */
     public function get_childrens(): array
     {
-        return $this->get_medias();
+        return ['song' => $this->get_medias()];
     }
 
     /**
      * Search for direct children of an object
      * @param string $name
+     * @return list<array{object_type: LibraryItemEnum, object_id: int}>
      */
-    public function get_children($name): array
+    public function get_children(string $name): array
     {
         debug_event(self::class, 'get_children ' . $name, 5);
 
@@ -577,10 +561,9 @@ class AlbumDisk extends database_object implements library_item, CatalogItemInte
 
     /**
      * display_art
-     * @param int $thumb
-     * @param bool $force
+     * @param array{width: int, height: int} $size
      */
-    public function display_art($thumb = 2, $force = false): void
+    public function display_art(array $size, bool $force = false): void
     {
         $album_id = null;
         $type     = null;
@@ -601,7 +584,7 @@ class AlbumDisk extends database_object implements library_item, CatalogItemInte
 
         if ($album_id !== null && $type !== null) {
             $title = '[' . ($this->get_artist_fullname() ?? $this->get_artist_fullname()) . '] ' . $this->get_fullname();
-            Art::display($type, $album_id, $title, $thumb, $this->get_link());
+            Art::display($type, $album_id, $title, $size, $this->get_link());
         }
     }
 
